@@ -11,7 +11,7 @@ persistence<-control$persistence
     H.eta <- function(G.inv, Z, R_inv) {
         h.eta <- G.inv
         h.y <- crossprod(Z, R_inv) %*% Z
-        Matrix(h.eta + h.y)
+        forceSymmetric(h.eta + h.y)
     }
     ltriangle <- function(x) {
         if (!is.null(dim(x)[2])) {
@@ -352,7 +352,7 @@ pattern.f.score <- function(R_i.parm, nyear, pattern.parmlist2, pattern.count, p
     colnames(Z) <- t_effects
     X_mat <- sparse.model.matrix(fixed_effects, Z_mat, drop.unused.levels = TRUE)
     X_mat <- X_mat[, !(colSums(abs(X_mat)) == 0), drop = FALSE]
-    if (rankMatrix(X_mat)[1] != dim(X_mat)[2]) {
+    if (rankMatrix(X_mat,method = 'qrLINPACK')[1] != dim(X_mat)[2]) {
     stop("WARNING: Fixed-effects design matrix not full-rank")
 
     }
